import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');
//The geoMercator() function in d3.js is used 
//to draw The spherical Mercator projection.
const projection = geoMercator()
  .translate([100, 75]) // position
  .scale([50]); // zoom

// given a JSON geometry object, to generates an SVG path
const pathGenerator = geoPath().projection(projection);

//Array of ten categorical colors which is returned as RGB hexadecimal strings. 
const colorScale = scaleOrdinal(schemeCategory10);

//loading data
json('https://raw.githubusercontent.com/wmgeolab/geoBoundaries/6b1d1e655cc4d67c9bbbc86fd0d53cffbfcf3641/releaseData/gbOpen/KAZ/ADM0/geoBoundaries-KAZ-ADM0.topojson'
).then((data) => {
  //extracting states data
  const countryShapes = feature(
    data,
    data.objects["2021_ELB_region"]
  );
  
countryShapes.features.shift()

	//Renders the path to a Canvas by appending path 
  //generated by pathgenerator to svg
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => { return(colorScale(d.properties.Elect_div))})
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

 
});